# Univariate Probability Distributions

This directory contains several univariate probability distributions, in addition to the UnivariateFitter object.

## UnivariateFitter

This object fits all / a subset of the probability distributions implemented in copulAX to the sample data, returning the 'best' distribution according to a given metric.

## Implemented Univariate Distributions

Currently the following univariate distributions are implemented in copulAX:
| Object / Module | Distribution |
| --- | --- |
| gamma | [Gamma](https://en.wikipedia.org/wiki/Gamma_distribution)|
| gh | [Generalized Hyperbolic](https://en.wikipedia.org/wiki/Generalised_hyperbolic_distribution)|
| gig | [Generalized Inverse Gaussian](https://en.wikipedia.org/wiki/Generalized_inverse_Gaussian_distribution)|
| ig | [Inverse-Gamma](https://en.wikipedia.org/wiki/Inverse-gamma_distribution)|
| lognormal | [Log-Normal](https://en.wikipedia.org/wiki/Log-normal_distribution)|
| normal | [Normal/Gaussian](https://en.wikipedia.org/wiki/Normal_distribution)|
| skewed_t | Skewed/Asymmetric Student's T|
| student_t | [Student's T](https://en.wikipedia.org/wiki/Student%27s_t-distribution)|
| uniform | [Continuous Uniform](https://en.wikipedia.org/wiki/Continuous_uniform_distribution)|
